==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/actions/updateRowConfig.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/actions/updateRowConfig.es", ['module', 'exports', 'require', './actions.es', './saveChanges.es', './updatePageContents.es', './updatePageEditorLayoutData.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.updateRowConfigAction = updateRowConfigAction;

  var _actions = require("./actions.es");

  var _saveChanges = require("./saveChanges.es");

  var _updatePageContents = require("./updatePageContents.es");

  var _updatePageEditorLayoutData = require("./updatePageEditorLayoutData.es");

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function updateRowConfigAction(rowId, configContent) {
    return function (dispatch) {
      dispatch((0, _saveChanges.enableSavingChangesStatusAction)());
      dispatch(updateRowConfig(rowId, configContent));
      dispatch((0, _updatePageEditorLayoutData.updatePageEditorLayoutDataAction)());
      dispatch((0, _saveChanges.updateLastSaveDateAction)());
      dispatch((0, _saveChanges.disableSavingChangesStatusAction)());
      var backgroundImage = configContent.backgroundImage;

      if (backgroundImage && (backgroundImage.fieldId !== undefined || backgroundImage.mappedField !== undefined)) {
        dispatch((0, _updatePageContents.updatePageContentsAction)());
      }
    };
  }

  function updateRowConfig(rowId, configContent) {
    return {
      config: _objectSpread({}, configContent),
      rowId: rowId,
      type: _actions.UPDATE_ROW_CONFIG
    };
  }
  //# sourceMappingURL=updateRowConfig.es.js.map
});
//# sourceMappingURL=updateRowConfig.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.126.jar: META-INF/resources/js/actions/updateRowConfig.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.126/js/actions/updateRowConfig.es", ['module', 'exports', 'require', './actions.es', './saveChanges.es', './updatePageContents.es', './updatePageEditorLayoutData.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.updateRowConfigAction = updateRowConfigAction;

  var _actions = require("./actions.es");

  var _saveChanges = require("./saveChanges.es");

  var _updatePageContents = require("./updatePageContents.es");

  var _updatePageEditorLayoutData = require("./updatePageEditorLayoutData.es");

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function updateRowConfigAction(rowId, configContent) {
    return function (dispatch) {
      dispatch((0, _saveChanges.enableSavingChangesStatusAction)());
      dispatch(updateRowConfig(rowId, configContent));
      dispatch((0, _updatePageEditorLayoutData.updatePageEditorLayoutDataAction)());
      dispatch((0, _saveChanges.updateLastSaveDateAction)());
      dispatch((0, _saveChanges.disableSavingChangesStatusAction)());
      var backgroundImage = configContent.backgroundImage;

      if (backgroundImage && (backgroundImage.fieldId !== undefined || backgroundImage.mappedField !== undefined)) {
        dispatch((0, _updatePageContents.updatePageContentsAction)());
      }
    };
  }

  function updateRowConfig(rowId, configContent) {
    return {
      config: _objectSpread({}, configContent),
      rowId: rowId,
      type: _actions.UPDATE_ROW_CONFIG
    };
  }
  //# sourceMappingURL=updateRowConfig.es.js.map
});
//# sourceMappingURL=updateRowConfig.es.js.map
